aboutsummaryrefslogtreecommitdiffstats
path: root/sources/shiboken6/generator/shiboken/cppgenerator.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'sources/shiboken6/generator/shiboken/cppgenerator.cpp')
-rw-r--r--sources/shiboken6/generator/shiboken/cppgenerator.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/sources/shiboken6/generator/shiboken/cppgenerator.cpp b/sources/shiboken6/generator/shiboken/cppgenerator.cpp
index 1d7649b18..82292b953 100644
--- a/sources/shiboken6/generator/shiboken/cppgenerator.cpp
+++ b/sources/shiboken6/generator/shiboken/cppgenerator.cpp
@@ -4161,7 +4161,7 @@ void CppGenerator::writeClassDefinition(QTextStream &s,
// privacy the same way. This worked before the heap types were used,
// because inheritance is not really checked for static types.
// Instead, we check this at runtime, see SbkObjectTypeTpNew.
- if (metaClass->fullName().startsWith(QLatin1String("PySide2.Qt"))) {
+ if (metaClass->fullName().startsWith(QLatin1String("PySide6.Qt"))) {
// PYSIDE-595: No idea how to do non-inheritance correctly.
// Since that is only relevant in shiboken, I used a shortcut for
// PySide.
@@ -4900,7 +4900,7 @@ void CppGenerator::writeSignatureInfo(QTextStream &s, const AbstractMetaFunction
for (const AbstractMetaFunction *f : overloads) {
QStringList args;
// PYSIDE-1328: `self`-ness cannot be computed in Python because there are mixed cases.
// Toplevel functions like `PySide2.QtCore.QEnum` are always self-less.
if (!(f->isStatic()) && f->ownerClass())
args << QLatin1String("self");
const AbstractMetaArgumentList &arguments = f->arguments();
@@ -4900,7 +4900,7 @@ void CppGenerator::writeSignatureInfo(QTextStream &s, const AbstractMetaFunction
QStringList args;
// PYSIDE-1328: `self`-ness cannot be computed in Python because there are mixed cases.
- // Toplevel functions like `PySide2.QtCore.QEnum` are always self-less.
+ // Toplevel functions like `PySide6.QtCore.QEnum` are always self-less.
if (!(f->isStatic()) && f->ownerClass())
args << QLatin1String("self");